pyxmpp2.constants

Package pyxmpp2 :: Module constants |
[hide private]

# Module constants

Common XMPP constants.

Variables | [hide private]
| XML_NS = ``'``http://www.w3.org/XML/1998/namespace``'``
| XML_QNP = ``'``{http://www.w3.org/XML/1998/namespace}``'``
| STREAM_NS = ``'``http://etherx.jabber.org/streams``'``
| STREAM_QNP = ``'``{http://etherx.jabber.org/streams}``'``
| STREAM_ROOT_TAG = ``'``{http://etherx.jabber.org/streams}stream``'``
| BIND_NS = ``'``urn:ietf:params:xml:ns:xmpp-bind``'``
| BIND_QNP = ``'``{urn:ietf:params:xml:ns:xmpp-bind}``'``
| SESSION_NS = ``'``urn:ietf:params:xml:ns:xmpp-session``'``
| SESSION_QNP = ``'``{urn:ietf:params:xml:ns:xmpp-session}``'``
| STANZA_CLIENT_NS = ``'``jabber:client``'``
| STANZA_CLIENT_QNP = ``'``{jabber:client}``'``
| STANZA_SERVER_NS = ``'``jabber:server``'``
| STANZA_SERVER_QNP = ``'``{jabber:server}``'``
| STANZA_NAMESPACES = ``(``'``jabber:client``'``,` `'``jabber:server``'``)``
| STANZA_ERROR_NS = ``'``urn:ietf:params:xml:ns:xmpp-stanzas``'``
| STANZA_ERROR_QNP = ``'``{urn:ietf:params:xml:ns:xmpp-stanzas}``'``
| STREAM_ERROR_NS = ``'``urn:ietf:params:xml:ns:xmpp-streams``'``
| STREAM_ERROR_QNP = ``'``{urn:ietf:params:xml:ns:xmpp-streams}``'``
| PYXMPP_ERROR_NS = ``'``http://pyxmpp.jajcus.net/xmlns/errors``'``
| PYXMPP_ERROR_QNP = ``'``{http://pyxmpp.jajcus.net/xmlns/errors}``'``
| SASL_NS = ``'``urn:ietf:params:xml:ns:xmpp-sasl``'``
| SASL_QNP = ``'``{urn:ietf:params:xml:ns:xmpp-sasl}``'``
| TLS_NS = ``'``urn:ietf:params:xml:ns:xmpp-tls``'``
| TLS_QNP = ``'``{urn:ietf:params:xml:ns:xmpp-tls}``'``
| XML_LANG_QNAME = ``'``{http://www.w3.org/XML/1998/namespace}lang``'``